@@ -5,3 +5,6 @@ from . import models
 
 class PayrollModelViewSet(ModelViewSet):
     model = models.PayrollModel
+
+class PayrollProcessViewSet(ModelViewSet):
+    model = models.PayrollProcess
\ No newline at end of file
